@@ -12,7 +12,7 @@
  ***************************************************************************/
 
 /***************************************************************************
- * Contains code from KDatePicker in kdelibs-3.1.2.
+ * Contains code from KDatePicker in tdelibs-3.1.2.
  * Original license message:
  *
     This file is part of the KDE libraries
@@ -43,8 +43,12 @@
  *                                                                         *
  ***************************************************************************/
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 // ----------------------------------------------------------------------------
-// QT Includes
+// TQt Includes
 #include <tqpainter.h>
 #include <tqdrawutil.h>
 #include <tqframe.h>
@@ -58,17 +62,17 @@
 #include <tqpushbutton.h>
 
 // ----------------------------------------------------------------------------
-// KDE Includes
-#include "kdecompat.h"
-#include <kglobal.h>
-#include <kapplication.h>
-#include <klocale.h>
+// TDE Includes
+#include <tdeversion.h>
+#include <tdeglobal.h>
+#include <tdeapplication.h>
+#include <tdelocale.h>
 #include <kiconloader.h>
 #include <klineedit.h>
 #include <kdebug.h>
 #include <knotifyclient.h>
 #include <kdatetbl.h> // for maximum re-use
-#include <kpopupmenu.h>
+#include <tdepopupmenu.h>
 
 #if KDE_IS_VERSION(3,2,0)
 #include <kcalendarsystem.h>
@@ -118,12 +122,12 @@ void kMyMoneyCalendar::init( const TQDate &dt )
 
   d->selectWeek = new TQToolButton( this );
 
-//  KIconLoader *kiconloader = KGlobal::iconLoader();
-  KPopupMenu* kpopupmenuNew = new KPopupMenu(this);
-  kpopupmenuNew->insertItem(i18n("Week"), this, TQT_SLOT(slotSetStyleWeekly()));
-  kpopupmenuNew->insertItem(i18n("Month"), this, TQT_SLOT(slotSetStyleMonthly()));
-/*  kpopupmenuNew->insertItem(i18n("3 Months"), this, TQT_SLOT(slotSetStyleQuarterly())); */
-  styleControl->setPopup(kpopupmenuNew);
+//  TDEIconLoader *kiconloader = TDEGlobal::iconLoader();
+  TDEPopupMenu* tdepopupmenuNew = new TDEPopupMenu(this);
+  tdepopupmenuNew->insertItem(i18n("Week"), this, TQ_SLOT(slotSetStyleWeekly()));
+  tdepopupmenuNew->insertItem(i18n("Month"), this, TQ_SLOT(slotSetStyleMonthly()));
+/*  tdepopupmenuNew->insertItem(i18n("3 Months"), this, TQ_SLOT(slotSetStyleQuarterly())); */
+  styleControl->setPopup(tdepopupmenuNew);
 
   TQToolTip::add(styleControl, i18n("Choose Style"));
   TQToolTip::add(yearForward, i18n("Next year"));
@@ -143,16 +147,16 @@ void kMyMoneyCalendar::init( const TQDate &dt )
   monthForward->setPixmap(BarIcon(TQString::fromLatin1("1rightarrow")));
   monthBackward->setPixmap(BarIcon(TQString::fromLatin1("1leftarrow")));
   setDate(dt); // set button texts
-  connect(table, TQT_SIGNAL(dateChanged(TQDate)), TQT_SLOT(dateChangedSlot(TQDate)));
-  connect(table, TQT_SIGNAL(tableClicked()), TQT_SLOT(tableClickedSlot()));
-  connect(monthForward, TQT_SIGNAL(clicked()), TQT_SLOT(monthForwardClicked()));
-  connect(monthBackward, TQT_SIGNAL(clicked()), TQT_SLOT(monthBackwardClicked()));
-  connect(yearForward, TQT_SIGNAL(clicked()), TQT_SLOT(yearForwardClicked()));
-  connect(yearBackward, TQT_SIGNAL(clicked()), TQT_SLOT(yearBackwardClicked()));
-  connect(d->selectWeek, TQT_SIGNAL(clicked()), TQT_SLOT(selectWeekClicked()));
-  connect(selectMonth, TQT_SIGNAL(clicked()), TQT_SLOT(selectMonthClicked()));
-  connect(selectYear, TQT_SIGNAL(clicked()), TQT_SLOT(selectYearClicked()));
-  connect(line, TQT_SIGNAL(returnPressed()), TQT_SLOT(lineEnterPressed()));
+  connect(table, TQ_SIGNAL(dateChanged(TQDate)), TQ_SLOT(dateChangedSlot(TQDate)));
+  connect(table, TQ_SIGNAL(tableClicked()), TQ_SLOT(tableClickedSlot()));
+  connect(monthForward, TQ_SIGNAL(clicked()), TQ_SLOT(monthForwardClicked()));
+  connect(monthBackward, TQ_SIGNAL(clicked()), TQ_SLOT(monthBackwardClicked()));
+  connect(yearForward, TQ_SIGNAL(clicked()), TQ_SLOT(yearForwardClicked()));
+  connect(yearBackward, TQ_SIGNAL(clicked()), TQ_SLOT(yearBackwardClicked()));
+  connect(d->selectWeek, TQ_SIGNAL(clicked()), TQ_SLOT(selectWeekClicked()));
+  connect(selectMonth, TQ_SIGNAL(clicked()), TQ_SLOT(selectMonthClicked()));
+  connect(selectYear, TQ_SIGNAL(clicked()), TQ_SLOT(selectYearClicked()));
+  connect(line, TQ_SIGNAL(returnPressed()), TQ_SLOT(lineEnterPressed()));
   if (table)
     table->setFocus();
 }
@@ -210,7 +214,7 @@ kMyMoneyCalendar::resizeEvent(TQResizeEvent*)
     // ----- calculate size of the month button:
     for(count=0; count<NoOfButtons; ++count) {
   if(buttons[count]==selectMonth) {
-      TQSize metricBound = style().tqsizeFromContents(TQStyle::CT_ToolButton, selectMonth, maxMonthRect);
+      TQSize metricBound = style().sizeFromContents(TQStyle::CT_ToolButton, selectMonth, maxMonthRect);
       sizes[count].setWidth(TQMAX(metricBound.width(), maxMonthRect.width()+2*TQApplication::style().pixelMetric(TQStyle::PM_ButtonMargin)));
   }
     }
@@ -260,7 +264,7 @@ void
 kMyMoneyCalendar::dateChangedSlot(TQDate date)
 {
     kdDebug() << "kMyMoneyCalendar::dateChangedSlot: date changed (" << date.year() << "/" << date.month() << "/" << date.day() << ")." << endl;
-    line->setText(KGlobal::locale()->formatDate(date, true));
+    line->setText(TDEGlobal::locale()->formatDate(date, true));
     d->selectWeek->setText(i18n("Week %1").arg(weekOfYear(date)));
     selectMonth->setText(MONTH_NAME(date.month(), date.year(), false));
     selectYear->setText(date.toString("yyyy"));
@@ -301,7 +305,7 @@ kMyMoneyCalendar::setDate(const TQDate& date)
   selectMonth->setText(MONTH_NAME(date.month(), date.year(), false));
   temp.setNum(date.year());
   selectYear->setText(temp);
-  line->setText(KGlobal::locale()->formatDate(date, true));
+  line->setText(TDEGlobal::locale()->formatDate(date, true));
   return true;
     } else {
   kdDebug() << "kMyMoneyCalendar::setDate: refusing to set invalid date." << endl;
@@ -336,14 +340,14 @@ kMyMoneyCalendar::yearBackwardClicked()
 void
 kMyMoneyCalendar::selectWeekClicked()
 {
-#if KDE_VERSION >= 310 && KDE_VERSION <= 314
+#if TDE_VERSION >= 310 && TDE_VERSION <= 314
   int week;
-  KPopupFrame* popup = new KPopupFrame(this);
+  TDEPopupFrame* popup = new TDEPopupFrame(this);
   KDateInternalWeekSelector* picker = new KDateInternalWeekSelector(/*fontsize, */popup);
   // -----
   picker->resize(picker->sizeHint());
   popup->setMainWidget(picker);
-  connect(picker, TQT_SIGNAL(closeMe(int)), popup, TQT_SLOT(close(int)));
+  connect(picker, TQ_SIGNAL(closeMe(int)), popup, TQ_SLOT(close(int)));
   picker->setFocus();
   if(popup->exec(d->selectWeek->mapToGlobal(TQPoint(0, d->selectWeek->height()))))
     {
@@ -375,15 +379,15 @@ kMyMoneyCalendar::selectWeekClicked()
 void
 kMyMoneyCalendar::selectMonthClicked()
 {
-#if KDE_VERSION >= 310 && KDE_VERSION <= 314
+#if TDE_VERSION >= 310 && TDE_VERSION <= 314
   int month;
-  KPopupFrame* popup = new KPopupFrame(this);
+  TDEPopupFrame* popup = new TDEPopupFrame(this);
   KDateInternalMonthPicker* picker = new KDateInternalMonthPicker(/*fontsize, */popup);
   // -----
   picker->resize(picker->sizeHint());
   popup->setMainWidget(picker);
   picker->setFocus();
-  connect(picker, TQT_SIGNAL(closeMe(int)), popup, TQT_SLOT(close(int)));
+  connect(picker, TQ_SIGNAL(closeMe(int)), popup, TQ_SLOT(close(int)));
   if(popup->exec(selectMonth->mapToGlobal(TQPoint(0, selectMonth->height()))))
     {
       TQDate date;
@@ -407,14 +411,14 @@ kMyMoneyCalendar::selectMonthClicked()
 void
 kMyMoneyCalendar::selectYearClicked()
 {
-#if KDE_VERSION >= 310 && KDE_VERSION <= 314
+#if TDE_VERSION >= 310 && TDE_VERSION <= 314
   int year;
-  KPopupFrame* popup = new KPopupFrame(this);
+  TDEPopupFrame* popup = new TDEPopupFrame(this);
   KDateInternalYearSelector* picker = new KDateInternalYearSelector(fontsize, popup);
   // -----
   picker->resize(picker->sizeHint());
   popup->setMainWidget(picker);
-  connect(picker, TQT_SIGNAL(closeMe(int)), popup, TQT_SLOT(close(int)));
+  connect(picker, TQ_SIGNAL(closeMe(int)), popup, TQ_SLOT(close(int)));
   picker->setFocus();
   if(popup->exec(selectYear->mapToGlobal(TQPoint(0, selectMonth->height()))))
     {
@@ -498,7 +502,7 @@ kMyMoneyCalendar::sizeHint() const
 
       if(buttons[count]==selectMonth)
   {
-    TQSize metricBound = style().tqsizeFromContents(TQStyle::CT_ToolButton, selectMonth, maxMonthRect);
+    TQSize metricBound = style().sizeFromContents(TQStyle::CT_ToolButton, selectMonth, maxMonthRect);
     cx+=TQMAX(metricBound.width(), maxMonthRect.width()+2*TQApplication::style().pixelMetric(TQStyle::PM_ButtonMargin));
   } else {
     cx+=sizes[count].width();
@@ -559,8 +563,8 @@ kMyMoneyCalendar::setCloseButton( bool enable )
         d->closeButton = new TQToolButton( this );
         TQToolTip::add(d->closeButton, i18n("Close"));
         d->closeButton->setPixmap( SmallIcon("remove") );
-        connect( d->closeButton, TQT_SIGNAL( clicked() ),
-                 topLevelWidget(), TQT_SLOT( close() ) );
+        connect( d->closeButton, TQ_SIGNAL( clicked() ),
+                 topLevelWidget(), TQ_SLOT( close() ) );
     }
     else {
         delete d->closeButton;
