@@ -53,7 +53,7 @@ class KDFrame;
   */
 class KDCHART_EXPORT KDChartCustomBox :public TQObject
 {
-    Q_OBJECT
+    TQ_OBJECT
   
     friend class KDChartPainter;
     friend class KDChartParams;
