@@ -1,4 +1,4 @@
-/* -*- Mode: C++ -*-
+/*
    KDChart - a multi-platform charting engine
 */
 
@@ -40,6 +40,7 @@
 #include <tqtextstream.h>
 #include <tqsimplerichtext.h>
 #include <tqdom.h>
+#include <tqvaluevector.h>
 #include <limits.h>
 
 #include <math.h>
@@ -54,12 +55,6 @@
 #include "KDChartAxisParams.h"
 #include "KDChartPropertySet.h"
 
-#if COMPAT_TQT_VERSION >= 0x030000
-#include <tqvaluevector.h>
-#else
-#include <tqarray.h>
-#endif
-
 /** \file KDChartParams.h
     \brief Header for all common chart parameters.
 
@@ -139,7 +134,7 @@ private:
 class KDCHART_EXPORT KDChartParams : public TQObject
 {
 
-    Q_OBJECT
+    TQ_OBJECT
   
     TQ_ENUMS(ChartType)
     TQ_ENUMS(SourceMode)
@@ -226,7 +221,7 @@ public:
 // MOC_SKIP_BEGIN
     class KDCHART_EXPORT KDChartFrameSettings
     {
-        // Q_OBJECT
+        // TQ_OBJECT
         // 
     public:
         KDChartFrameSettings();
@@ -638,12 +633,12 @@ public slots:
         }
 
 
-    void setShadowPattern( Qt::BrushStyle style ) {
+    void setShadowPattern( TQt::BrushStyle style ) {
         _shadowPattern = style;
         emit changed();
     }
 
-    Qt::BrushStyle shadowPattern() const {
+    TQt::BrushStyle shadowPattern() const {
         return _shadowPattern;
     }
 
@@ -673,13 +668,13 @@ public slots:
         }
 
 
-    void setOutlineDataLineStyle( Qt::PenStyle style )
+    void setOutlineDataLineStyle( TQt::PenStyle style )
         {
             _outlineDataLineStyle = style;
             emit changed();
         }
 
-    Qt::PenStyle outlineDataLineStyle() const
+    TQt::PenStyle outlineDataLineStyle() const
         {
             return _outlineDataLineStyle;
         }
@@ -754,7 +749,7 @@ public slots:
                                uint chart = KDCHART_ALL_CHARTS );
 
     void setDataValuesColors( const TQColor* color = KDCHART_DATA_VALUE_AUTO_COLOR,
-                              const TQBrush& background = TQBrush(Qt::NoBrush),
+                              const TQBrush& background = TQBrush(TQt::NoBrush),
                               uint chart = KDCHART_ALL_CHARTS );
 
     // Note if you change the parameters here, then you must also change them in wrappers/KDChartParametersWrapper.h
@@ -1155,9 +1150,9 @@ public slots:
             return _lineColor;
         }
 
-    void setLineStyle( Qt::PenStyle style, uint dataset=KDCHART_GLOBAL_LINE_STYLE );
+    void setLineStyle( TQt::PenStyle style, uint dataset=KDCHART_GLOBAL_LINE_STYLE );
 
-    Qt::PenStyle lineStyle( uint dataset=KDCHART_GLOBAL_LINE_STYLE ) const;
+    TQt::PenStyle lineStyle( uint dataset=KDCHART_GLOBAL_LINE_STYLE ) const;
 
 
     void setThreeDLines( bool threeD ) {
@@ -1871,13 +1866,13 @@ public slots:
             return _legendPosition;
         }
 
-    void setLegendOrientation( Qt::Orientation orientation )
+    void setLegendOrientation( TQt::Orientation orientation )
         {
             _legendOrientation = orientation;
             emit changed();
         }
 
-    Qt::Orientation legendOrientation() const
+    TQt::Orientation legendOrientation() const
         {
             return _legendOrientation;
         }
@@ -2097,11 +2092,7 @@ public slots:
                        uint& chart ) const;
 
 public:
-#if COMPAT_TQT_VERSION >= 0x030000
     typedef TQValueVector<uint> AxesArray;
-#else
-    typedef TQArray<uint> AxesArray;
-#endif
 
 public slots:
     bool chartAxes( uint chart, uint& cnt, AxesArray& axes ) const;
@@ -2552,14 +2543,14 @@ private:
     uint _maxDatasetSourceMode;
     KDChartPropertySetList _propertySetList;
     double _shadowBrightnessFactor;
-    Qt::BrushStyle _shadowPattern;
+    TQt::BrushStyle _shadowPattern;
     bool _threeDShadowColors;
     uint _maxDatasetColor;
     TQMap < uint, TQColor > _dataColorsShadow1;
     TQMap < uint, TQColor > _dataColorsShadow2;
     TQColor _outlineDataColor;
     uint _outlineDataLineWidth;
-    Qt::PenStyle _outlineDataLineStyle;
+    TQt::PenStyle _outlineDataLineStyle;
 
 
     struct PrintDataValuesSettings {
@@ -2621,8 +2612,8 @@ private:
     TQSize _lineMarkerSize;
     TQColor _lineColor;
     int _lineWidth;
-    Qt::PenStyle _lineStyle;
-    typedef TQMap<uint, Qt::PenStyle> LineStyleMap;
+    TQt::PenStyle _lineStyle;
+    typedef TQMap<uint, TQt::PenStyle> LineStyleMap;
     LineStyleMap _datasetLineStyles;
     AreaChartSubType _areaChartSubType;
     AreaLocation _areaLocation;
@@ -2709,7 +2700,7 @@ private:
     // LEGENDS
 
     LegendPosition _legendPosition;
-    Qt::Orientation _legendOrientation;
+    TQt::Orientation _legendOrientation;
     bool _legendShowLines;
     LegendSource _legendSource;
     TQMap < int, TQString > _legendText;
