@@ -95,13 +95,7 @@ void KDChartPolarPainter::paintData( TQPainter* painter,
     //
 
     const TQWMatrix & world = painter->worldMatrix();
-    ourClipRect =
-#if COMPAT_TQT_VERSION >= 0x030000
-        world.mapRect( ourClipRect );
-#else
-    world.map( ourClipRect );
-#endif
-
+    ourClipRect = world.mapRect( ourClipRect );
     painter->setClipRect( ourClipRect );
 
 
