@@ -1,4 +1,4 @@
-/* -*- Mode: C++ -*-
+/*
    KDChart - a multi-platform charting engine
    */
 
@@ -65,7 +65,7 @@ instead of the value that is stored locally.
 */
 class KDCHART_EXPORT KDChartPropertySet :public TQObject
 {
-    Q_OBJECT
+    TQ_OBJECT
     
     TQ_ENUMS( SpecialDataPropertyID )
 
@@ -521,7 +521,7 @@ public slots:
       \sa setLineWidth, setLineColor, setShowMarker
       \sa hasOwnLineWidth, hasOwnLineColor, hasOwnLineStyle, hasOwnShowMarker
       */
-    void setLineStyle( int idLineStyle, const Qt::PenStyle& lineStyle )
+    void setLineStyle( int idLineStyle, const TQt::PenStyle& lineStyle )
     {
         mIdLineStyle = idLineStyle;
         mLineStyle =   lineStyle;
@@ -559,7 +559,7 @@ public slots:
       \sa setLineWidth, setLineColor, setLineStyle, setShowMarker
       \sa hasOwnLineWidth, hasOwnLineColor, hasOwnShowMarker
       */
-    bool hasOwnLineStyle( int& idLineStyle, Qt::PenStyle& lineStyle )
+    bool hasOwnLineStyle( int& idLineStyle, TQt::PenStyle& lineStyle )
     {
         idLineStyle = mIdLineStyle;
         if( OwnID == mIdLineStyle ){
@@ -877,12 +877,12 @@ public slots:
         }
         return false;
     }
-    void setExtraLinesStyle( int idExtraLinesStyle, const Qt::PenStyle extraLinesStyle )
+    void setExtraLinesStyle( int idExtraLinesStyle, const TQt::PenStyle extraLinesStyle )
     {
         mIdExtraLinesStyle = idExtraLinesStyle;
         mExtraLinesStyle =   extraLinesStyle;
     }
-    bool hasOwnExtraLinesStyle( int& idExtraLinesStyle, Qt::PenStyle& extraLinesStyle )
+    bool hasOwnExtraLinesStyle( int& idExtraLinesStyle, TQt::PenStyle& extraLinesStyle )
     {
         idExtraLinesStyle = mIdExtraLinesStyle;
         if( OwnID == idExtraLinesStyle ){
@@ -961,7 +961,7 @@ private:
     // IDs:                     values used if ID == OwnID:
     int mIdLineWidth;         int          mLineWidth;
     int mIdLineColor;         TQColor       mLineColor;
-    int mIdLineStyle;         Qt::PenStyle mLineStyle;
+    int mIdLineStyle;         TQt::PenStyle mLineStyle;
     int mIdShowMarker;        bool         mShowMarker;
     int mIdMarkerSize;        TQSize        mMarkerSize;
     int mIdMarkerColor;       TQColor       mMarkerColor;
@@ -972,7 +972,7 @@ private:
     int mIdExtraLinesLength;  int          mExtraLinesLength;
     int mIdExtraLinesWidth;   int          mExtraLinesWidth;
     int mIdExtraLinesColor;   TQColor       mExtraLinesColor;
-    int mIdExtraLinesStyle;   Qt::PenStyle mExtraLinesStyle;
+    int mIdExtraLinesStyle;   TQt::PenStyle mExtraLinesStyle;
     int mIdExtraMarkersAlign; uint         mExtraMarkersAlign;
     int mIdExtraMarkersSize;  TQSize        mExtraMarkersSize;
     int mIdExtraMarkersColor; TQColor       mExtraMarkersColor;
